@@ -55,7 +55,7 @@ check.gamViz <- function(obj,
   if( inherits(obj, "qgam") ){ return( check.qgam(obj) ) }
   
   type <- match.arg(type)
-  if (type == "auto") { type <- .getResTypeAndMethod(obj$family$family)$type }
+  if (type == "auto") { type <- .getResTypeAndMethod(obj$family)$type }
   
   # Overwriting user-provided argument lists
   a.all <- .argMaster("check.gamViz")
@@ -63,6 +63,10 @@ check.gamViz <- function(obj,
     assign(nam, .argSetup(a.all[[nam]], get(nam), nam, verbose = FALSE), envir = environment())
   }
   
+  if(is.null(a.qq$type)){
+    a.qq$type <- type
+  }
+  
   resid <- residuals(obj, type = type)
  
   # Sample if too many points (> maxpo) 
